Video demo on YouTube : https://youtu.be/PMLaksRtqyk

# hwglance: Glance at your computer status
Need something to keep an eye on your system recources?

```
pip install hwglance
```

# -r --refresh INT
	Refresh = default refresh rate, aka the time for intervals (in seconds). Can be float, e.g. 0.2
	But I like 0.5 !

# -w --wave (True/False) or (1/0)
	At the bottom are some waves, at least, it aims to be.
	Set this to (True) to enable, or (False) to disable this amazing feature.

# -c --coloring (True/False) or (1/0)
	The top and bottom banners (Title / Wavey thingy) change color.
	Set this to (True) to enable, or (False) to disable this amazing feature. 

# -s --services (True/False) or (1/0)
	Default: False
	Enable this setting to get IP address information.

![image](https://user-images.githubusercontent.com/36036245/48550671-ba87b700-e8d3-11e8-949a-e58c2287651d.png)
